Overscroll + chevrons enabled (1 second animations)

Home
News
Contact
About
Support
Blog
Tools
Base
Custom
More
Logo
Friends
Partners
People
Work
‹
›

Chevrons enabled 1/2 second animations.

Home
News
Contact
About
Support
Blog
Tools
Base
Custom
More
Logo
Friends
Partners
People
Work
‹
›

Plain scrolling

Home
News
Contact
About
Support
Blog
Tools
Base
Custom
More
Logo
Friends
Partners
People
Work

## Horizontal Scrollable Menu Tester

Resize, drag menu items and/or click on chevrons to test.